@@ -118,10 +118,10 @@ clean_names.character <- function(x, include_names = FALSE, ...) {
   pattern <- c(
     "as.factor", "as.numeric", "factor", "frailty", "offset", "log1p", "log10",
     "log2", "log(log", "scale(log", "log", "lag", "diff", "lspline", "as.logical",
-    "logical", "pspline", "scale(poly", "poly", "catg", "asis", "matrx", "pol",
-    "strata", "strat", "scale", "scored", "interaction", "sqrt", "sin", "cos",
-    "tan", "acos", "asin", "atan", "atan2", "exp", "lsp", "rcs", "pb", "lo",
-    "bs", "ns", "mSpline", "bSpline", "t2", "te", "ti", "tt", # need to be fixed first "mmc", "mm",
+    "logical", "ordered", "as.ordered", "pspline", "scale(poly", "poly", "catg",
+    "asis", "matrx", "pol", "strata", "strat", "scale", "scored", "interaction",
+    "sqrt", "sin", "cos", "tan", "acos", "asin", "atan", "atan2", "exp", "lsp",
+    "rcs", "pb", "lo", "bs", "ns", "mSpline", "bSpline", "t2", "te", "ti", "tt", # need to be fixed first "mmc", "mm",
     "mi", "mo", "gp", "s", "I"
   )
 
