@@ -4,8 +4,9 @@
 #' @description Checks if model has an intercept.
 #'
 #' @param x A model object.
+#' @param verbose Toggle warnings.
 #'
-#' @return \code{TRUE} if \code{x} has an intercept, \code{FALSE} otherwise.
+#' @return `TRUE` if `x` has an intercept, `FALSE` otherwise.
 #'
 #' @examples
 #' model <- lm(mpg ~ 0 + gear, data = mtcars)
@@ -22,14 +23,21 @@
 #'   has_intercept(model)
 #' }
 #' @export
-has_intercept <- function(x) {
+has_intercept <- function(x, verbose = TRUE) {
+  f <- find_formula(x)
   if (is_multivariate(x)) {
-    unlist(lapply(find_terms(x), .check_for_intercept))
+    lapply(f, .check_for_intercept, verbose = verbose)
   } else {
-    .check_for_intercept(find_terms(x))
+    .check_for_intercept(f, verbose)
   }
 }
 
-.check_for_intercept <- function(vars) {
-  !any(c("0", "-1") %in% vars[["conditional"]])
+.check_for_intercept <- function(f, verbose = TRUE) {
+  if (!is.null(f$conditional)) {
+    f_terms <- stats::terms(f$conditional)
+    intercept <- as.vector(attr(f_terms, "intercept"))
+    return(intercept == 1)
+  } else if (verbose) {
+    warning(format_message("Cannot extract terms from model formula."), call. = FALSE)
+  }
 }
