@@ -1,17 +1,19 @@
-if (requiet("testthat") &&
-  requiet("insight") &&
+if (
+
   requiet("survival") &&
-  requiet("lme4") &&
-  requiet("nlme") &&
-  requiet("bdsmatrix") &&
-  requiet("coxme")) {
+    requiet("lme4") &&
+    requiet("nlme") &&
+    requiet("bdsmatrix") &&
+    requiet("coxme")) {
   set.seed(1234)
   lung$inst2 <- sample(1:10, size = nrow(lung), replace = TRUE)
   lung <- subset(lung, subset = ph.ecog %in% 0:2)
   lung$ph.ecog <- factor(lung$ph.ecog, labels = c("good", "ok", "limited"))
 
-  m1 <- coxme(Surv(time, status) ~ ph.ecog + age + (1 | inst), lung)
-  m2 <- coxme(Surv(time, status) ~ ph.ecog + age + (1 | inst) + (1 | inst2), lung)
+  d <<- lung
+
+  m1 <- coxme(Surv(time, status) ~ ph.ecog + age + (1 | inst), d)
+  m2 <- coxme(Surv(time, status) ~ ph.ecog + age + (1 | inst) + (1 | inst2), d)
 
   test_that("model_info", {
     expect_true(model_info(m1)$is_logit)
@@ -34,18 +36,17 @@ if (requiet("testthat") &&
   })
 
   test_that("link_inverse", {
-    expect_equal(link_inverse(m1)(.2), plogis(.2), tolerance = 1e-5)
-    expect_equal(link_inverse(m2)(.2), plogis(.2), tolerance = 1e-5)
+    expect_equal(link_inverse(m1)(0.2), plogis(0.2), tolerance = 1e-5)
+    expect_equal(link_inverse(m2)(0.2), plogis(0.2), tolerance = 1e-5)
   })
 
   test_that("get_data", {
-    expect_equal(nrow(get_data(m1)), 226)
+    expect_equal(nrow(get_data(m1)), 225)
     expect_equal(
       colnames(get_data(m1)),
       c(
         "time",
         "status",
-        "Surv(time, status)",
         "ph.ecog",
         "age",
         "inst"
@@ -56,7 +57,6 @@ if (requiet("testthat") &&
       c(
         "time",
         "status",
-        "Surv(time, status)",
         "ph.ecog",
         "age",
         "inst",
@@ -148,9 +148,9 @@ if (requiet("testthat") &&
 
   test_that("get_response", {
     expect_equal(colnames(get_response(m1)), c("time", "status"))
-    expect_equal(nrow(get_response(m1)), 226)
+    expect_equal(nrow(get_response(m1)), 225)
     expect_equal(colnames(get_response(m1)), c("time", "status"))
-    expect_equal(nrow(get_response(m2)), 226)
+    expect_equal(nrow(get_response(m2)), 225)
   })
 
   test_that("linkfun", {
