@@ -16,11 +16,11 @@ unloadNamespace("gam")
 
 .runThisTest <- Sys.getenv("RunAllinsightTests") == "yes"
 
-if (.runThisTest && !osx && requiet("testthat") && requiet("insight") && requiet("gamm4")) {
+if (.runThisTest && !osx && requiet("gamm4")) {
   set.seed(0)
   void <- capture.output(dat <- gamSim(1, n = 400, scale = 2)) ## simulate 4 term additive truth
   dat$fac <- fac <- as.factor(sample(1:20, 400, replace = TRUE))
-  dat$y <- dat$y + model.matrix(~ fac - 1) %*% rnorm(20) * .5
+  dat$y <- dat$y + model.matrix(~ fac - 1) %*% rnorm(20) * 0.5
 
   m1 <- gamm4(y ~ s(x0) + x1 + s(x2),
     data = dat,
@@ -50,7 +50,7 @@ if (.runThisTest && !osx && requiet("testthat") && requiet("insight") && requiet
   })
 
   test_that("link_inverse", {
-    expect_equal(link_inverse(m1)(.2), .2, tolerance = 1e-5)
+    expect_equal(link_inverse(m1)(0.2), 0.2, tolerance = 1e-5)
   })
 
   test_that("get_data", {
