@@ -1,4 +1,4 @@
-if (requiet("testthat") && requiet("insight") && requiet("MASS")) {
+if (requiet("MASS")) {
   data(quine)
   clotting <- data.frame(
     u = c(5, 10, 15, 20, 30, 40, 60, 80, 100),
