@@ -14,7 +14,7 @@ osx <- tryCatch(
 
 .runThisTest <- Sys.getenv("RunAllinsightTests") == "yes"
 
-if (.runThisTest && !osx && requiet("testthat") && requiet("insight") && requiet("nonnest2")) {
+if (.runThisTest && !osx && requiet("nonnest2")) {
   data(iris)
   data(mtcars)
 
@@ -133,21 +133,22 @@ if (.runThisTest && !osx && requiet("testthat") && requiet("insight") && requiet
   })
 
   test_that("get_loglikelihood - ivreg", {
-    if (requiet("ivreg")) {
-      data("CigaretteDemand", package = "ivreg")
-      x <- ivreg::ivreg(log(packs) ~ log(rprice) + log(rincome) | salestax + log(rincome), data = CigaretteDemand)
+    requiet("ivreg")
+    data("CigaretteDemand", package = "ivreg")
+    x <- ivreg::ivreg(log(packs) ~ log(rprice) + log(rincome) | salestax + log(rincome), data = CigaretteDemand)
 
-      ll <- loglikelihood(x)
-      expect_equal(as.numeric(ll), 13.26255, tolerance = 1e-3)
-    }
+    ll <- loglikelihood(x)
+    expect_equal(as.numeric(ll), 13.26255, tolerance = 1e-3)
   })
 
   test_that("get_loglikelihood - plm", {
     if (requiet("plm")) {
       data("Produc", package = "plm")
-      x <- suppressWarnings(plm::plm(log(gsp) ~ log(pcap) + log(pc) + log(emp) + unemp,
-        data = Produc, index = c("state", "year")
-      ))
+      x <- suppressWarnings(
+        plm::plm(log(gsp) ~ log(pcap) + log(pc) + log(emp) + unemp,
+          data = Produc, index = c("state", "year")
+        )
+      )
 
       ll <- loglikelihood(x)
       expect_equal(as.numeric(ll), 1534.532, tolerance = 1e-3)
