@@ -1,4 +1,4 @@
-if (require("testthat") && require("insight") && require("lme4")) {
+if (requiet("lme4")) {
   data(mtcars)
   m1 <- lmer(mpg ~ am + (1 | cyl), data = mtcars)
   m2 <- lm(mpg ~ am, data = mtcars)
@@ -9,7 +9,7 @@ if (require("testthat") && require("insight") && require("lme4")) {
   })
 
   set.seed(123)
-  mtcars$w <- abs(rnorm(nrow(mtcars), sd = .5))
+  mtcars$w <- abs(rnorm(nrow(mtcars), sd = 0.5))
 
   m1 <- lmer(mpg ~ am + (1 | cyl), data = mtcars, weights = w)
   m2 <- lm(mpg ~ am, data = mtcars, weights = w)
